from distutils.core import setup
setup(
  name = 'lalisa',
  packages = ['lalisa'],
  version = '0.1',
  license='MIT',
  description = 'DESCRIPTION',
  author = 'nshout',
  url = 'https://github.com/lalisa-studio/lalisa',
  keywords = ['protection', 'security', 'obfuscation'],
  install_requires=[],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3.11',
  ],
)
